# AllowableStress
## 許容応力の確率論的決定法
#### Shinsuke Sakai   
 Emeritus Professor, The University of Tokyo, Japan   
 Visiting Professor, Yokohama National University, Japan

### Overview
規格や標準において各種強度の許容応力値を設定するにあたり，強度実験で得られたサンプルデータに基づいて決定することが求められることがある。この場合，許容応力は目標とする信頼度や信頼水準を満足するように，サンプルサイズを加味した上で確率論的に決定する必要がでてくる。近年，許容応力を確率論的に決定することの必要性が高まっている。確率論的評価に資するためのパッケージを提供する。なお，確率分布は正規分布であるものとしている。ただし，対数正規分布の場合にも，応用できるので，最後にその利用法を示している



### インストール方法
pip install AllowableStress

### 参考文献
[許容応力の確率論的決定法](https://www.jstage.jst.go.jp/article/hpi/60/1/60_18/_article/-char/ja/)







